==> haskell-heredoc-0.2.0.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heredoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heredoc
version:              0.2.0.0
visibility:           public
id:                   heredoc-0.2.0.0-3JaZslz7erTJPvrWiBGHRr
key:                  heredoc-0.2.0.0-3JaZslz7erTJPvrWiBGHRr
license:              LicenseRef-PublicDomain
maintainer:           jameshfisher@gmail.com
author:               James H. Fisher
homepage:             http://hackage.haskell.org/package/heredoc
synopsis:             multi-line string / here document using QuasiQuotes
description:          multi-line string / here document using QuasiQuotes
category:             Text
abi:                  69086e2b34cad0ad4d9f4bfccbc42c87
exposed:              True
exposed-modules:      Text.Heredoc
import-dirs:          /usr/lib/ghc-8.8.3/site-local/heredoc-0.2.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/heredoc-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/heredoc-0.2.0.0
hs-libraries:         HSheredoc-0.2.0.0-3JaZslz7erTJPvrWiBGHRr
depends:              base-4.13.0.0 template-haskell-2.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-heredoc/html/heredoc.haddock
haddock-html:         /usr/share/doc/haskell-heredoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heredoc-0.2.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heredoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heredoc
version:              0.2.0.0
visibility:           public
id:                   heredoc-0.2.0.0-2Mv6sG9hTuO2hkaj42CFts
key:                  heredoc-0.2.0.0-2Mv6sG9hTuO2hkaj42CFts
license:              LicenseRef-PublicDomain
maintainer:           jameshfisher@gmail.com
author:               James H. Fisher
homepage:             http://hackage.haskell.org/package/heredoc
synopsis:             multi-line string / here document using QuasiQuotes
description:          multi-line string / here document using QuasiQuotes
category:             Text
abi:                  d031550f62e506e2dcec71da8099c139
exposed:              True
exposed-modules:      Text.Heredoc
import-dirs:          /usr/lib/ghc-8.10.1/site-local/heredoc-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/heredoc-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/heredoc-0.2.0.0
hs-libraries:         HSheredoc-0.2.0.0-2Mv6sG9hTuO2hkaj42CFts
depends:              base-4.14.0.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-heredoc/html/heredoc.haddock
haddock-html:         /usr/share/doc/haskell-heredoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
